@@ -819,7 +819,7 @@ class EntitySet(object):
                         lti.index = entity.df[entity.index].copy()
                         lti = lti.apply(lambda x: None)
                     elif is_instance(entity.df, ks, 'DataFrame'):
-                        lti = ks.Series(index=lti.to_list()).rename(lti.name)
+                        lti = ks.Series(pd.Series(index=lti.to_list(), name=lti.name))
                     else:
                         lti[:] = None
                 entity.last_time_index = lti
