@@ -6,7 +6,6 @@ from datetime import datetime
 from itertools import combinations
 from random import randint
 
-import composeml as cp
 import numpy as np
 import pandas as pd
 import psutil
@@ -153,30 +152,12 @@ def test_cfm_warns_dask_cutoff_time(es):
                                  cutoff_time=cutoff_time)
 
 
-def test_cfm_compose(es):
-    def label_func(df):
-        return df['value'].sum() > 10
-
-    lm = cp.LabelMaker(
-        target_entity='id',
-        time_index='datetime',
-        labeling_function=label_func,
-        window_size='1m'
-    )
-
-    df = es['log'].df
-    df = to_pandas(df)
-    labels = lm.search(
-        df,
-        num_examples_per_instance=-1
-    )
-    labels = labels.rename(columns={'cutoff_time': 'time'})
-
+def test_cfm_compose(es, lt):
     property_feature = ft.Feature(es['log']['value']) > 10
 
     feature_matrix = calculate_feature_matrix([property_feature],
                                               es,
-                                              cutoff_time=labels,
+                                              cutoff_time=lt,
                                               verbose=True)
     feature_matrix = to_pandas(feature_matrix, index='id', sort_index=True)
 
@@ -184,28 +165,30 @@ def test_cfm_compose(es):
             feature_matrix['label_func']).values.all()
 
 
-def test_cfm_dask_compose(dask_es):
-    def label_func(df):
-        return df['value'].sum() > 10
+def test_cfm_compose_approximate(es, lt):
+    if not all(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
+        pytest.xfail('dask does not support approximate')
 
-    lm = cp.LabelMaker(
-        target_entity='id',
-        time_index='datetime',
-        labeling_function=label_func,
-        window_size='3m'
-    )
+    property_feature = ft.Feature(es['log']['value']) > 10
 
-    labels = lm.search(
-        dask_es['log'].df.compute(),
-        num_examples_per_instance=-1
-    )
-    labels = labels.rename(columns={'cutoff_time': 'time'})
+    feature_matrix = calculate_feature_matrix([property_feature],
+                                              es,
+                                              cutoff_time=lt,
+                                              approximate='1s',
+                                              verbose=True)
+    assert(type(feature_matrix) == pd.core.frame.DataFrame)
+    feature_matrix = to_pandas(feature_matrix, index='id', sort_index=True)
 
+    assert (feature_matrix[property_feature.get_name()] ==
+            feature_matrix['label_func']).values.all()
+
+
+def test_cfm_dask_compose(dask_es, lt):
     property_feature = ft.Feature(dask_es['log']['value']) > 10
 
     feature_matrix = calculate_feature_matrix([property_feature],
                                               dask_es,
-                                              cutoff_time=labels,
+                                              cutoff_time=lt,
                                               verbose=True)
     feature_matrix = feature_matrix.compute()
 
@@ -1084,6 +1067,41 @@ def test_cutoff_time_extra_columns_approximate(pd_es):
     assert (fm['label'].values == cutoff_df['label'].values).all()
 
 
+def test_cutoff_time_extra_columns_same_name(es):
+    if not all(isinstance(entity.df, pd.DataFrame) for entity in es.entities):
+        pytest.xfail('Distributed result not ordered')
+    agg_feat = ft.Feature(es['customers']['id'], parent_entity=es[u'régions'], primitive=Count)
+    dfeat = DirectFeature(agg_feat, es['customers'])
+
+    cutoff_df = pd.DataFrame({'time': [pd.Timestamp('2011-04-09 10:30:06'),
+                                       pd.Timestamp('2011-04-09 10:30:03'),
+                                       pd.Timestamp('2011-04-08 10:30:00')],
+                              'instance_id': [0, 1, 0],
+                              'régions.COUNT(customers)': [False, False, True]},
+                             columns=['time', 'instance_id', 'régions.COUNT(customers)'])
+    fm = calculate_feature_matrix([dfeat], es, cutoff_time=cutoff_df)
+
+    assert (fm['régions.COUNT(customers)'].values == cutoff_df['régions.COUNT(customers)'].values).all()
+
+
+def test_cutoff_time_extra_columns_same_name_approximate(pd_es):
+    agg_feat = ft.Feature(pd_es['customers']['id'], parent_entity=pd_es[u'régions'], primitive=Count)
+    dfeat = DirectFeature(agg_feat, pd_es['customers'])
+
+    cutoff_df = pd.DataFrame({'time': [pd.Timestamp('2011-04-09 10:30:06'),
+                                       pd.Timestamp('2011-04-09 10:30:03'),
+                                       pd.Timestamp('2011-04-08 10:30:00')],
+                              'instance_id': [0, 1, 0],
+                              'régions.COUNT(customers)': [False, False, True]},
+                             columns=['time', 'instance_id', 'régions.COUNT(customers)'])
+    fm = calculate_feature_matrix([dfeat],
+                                  pd_es,
+                                  cutoff_time=cutoff_df,
+                                  approximate="2 days")
+
+    assert (fm['régions.COUNT(customers)'].values == cutoff_df['régions.COUNT(customers)'].values).all()
+
+
 def test_instances_after_cutoff_time_removed(es):
     property_feature = ft.Feature(es['log']['id'], parent_entity=es['customers'], primitive=Count)
     cutoff_time = datetime(2011, 4, 8)
