@@ -133,7 +133,7 @@ def test_add_relationship_errors_on_dtype_mismatch(es):
         'value_many_nans': variable_types.Numeric,
         'priority_level': variable_types.Ordinal,
         'purchased': variable_types.Boolean,
-        'comments': variable_types.Text
+        'comments': variable_types.NaturalLanguage
     }
     assert set(log_variable_types) == set(log_2_df.columns)
     es.entity_from_dataframe(entity_id='log2',
