@@ -1,5 +1,7 @@
 import json
 import os
+import tempfile
+from urllib.request import urlretrieve
 
 import boto3
 import pandas as pd
@@ -21,7 +23,7 @@ ks = import_or_none('databricks.koalas')
 BUCKET_NAME = "test-bucket"
 WRITE_KEY_NAME = "test-key"
 TEST_S3_URL = "s3://{}/{}".format(BUCKET_NAME, WRITE_KEY_NAME)
-TEST_FILE = "test_serialization_data_entityset_schema_5.0.0.tar"
+TEST_FILE = "test_serialization_data_entityset_schema_5.1.0.tar"
 S3_URL = "s3://featuretools-static/" + TEST_FILE
 URL = "https://featuretools-static.s3.amazonaws.com/" + TEST_FILE
 TEST_KEY = "test_access_key_es"
@@ -78,6 +80,15 @@ def test_unknown_variable_description(es):
     assert(variable.dtype == 'unknown')
 
 
+def test_custom_description_variable_description(es):
+    for entity in es.entities:
+        for variable in entity.variables:
+            variable.description = 'a custom description'
+            description = variable.to_data_description()
+            _variable = deserialize.description_to_variable(description, entity=entity)
+            assert _variable.description == 'a custom description'
+
+
 def test_entity_descriptions(es):
     _es = EntitySet(es.id)
     for entity in es.metadata.entities:
@@ -363,6 +374,14 @@ def test_serialize_subdirs_not_removed(es, tmpdir):
         assert '__SAMPLE_TEXT__' not in json.load(f)
 
 
+def test_deserialize_local_tar(es):
+    with tempfile.TemporaryDirectory() as tmpdir:
+        temp_tar_filepath = os.path.join(tmpdir, TEST_FILE)
+        urlretrieve(URL, filename=temp_tar_filepath)
+        new_es = deserialize.read_entityset(temp_tar_filepath)
+        assert es.__eq__(new_es, deep=True)
+
+
 def test_deserialize_url_csv(es):
     new_es = deserialize.read_entityset(URL)
     assert es.__eq__(new_es, deep=True)
